"""
Plugs media models
"""

import uuid

from django.conf import settings
from django.db import models

from plugs_core import mixins

class Media(mixins.Timestampable, models.Model):
    """
    Media Model
    """
    name = models.CharField(max_length=255, null=True, blank=True)
    file = models.FileField(max_length=255, upload_to='%Y/%m/%d/')
    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True)

    def save(self, *args, **kwargs):
        if not self.pk:
            parts = self.file.name.split('.')
            num = len(parts) - 1
            extension = '.' + parts[num]
            del parts[num]
            name = ''.join(map(str, parts))
            self.file.name = str(uuid.uuid4()) + extension
            self.name = name
        super(Media, self).save(*args, **kwargs)

    # pylint: disable=R0903
    class Meta:
        """
        Metaclass definition
        """
        ordering = ('pk', )
        verbose_name = 'media'
        verbose_name_plural = 'media'



"""
Plugs Media Views
"""
from rest_framework import permissions
from rest_framework.viewsets import ReadOnlyModelViewSet

from plugs_core import viewsets

from plugs_media import models
from plugs_media import serializers
from plugs_media.permissions import IsOwnerOrReadOnly

from plugs_filter.decorators import auto_filters

@auto_filters
class MediaViewSet(viewsets.CreateReadViewSet):
    """
    Media Endpoint does not support update or delete operations
    """
    queryset = models.Media.objects.all()
    serializer_class = serializers.MediaSerializer
    permission_classes = [IsOwnerOrReadOnly]
    auto_filters_fields = ('id', )

    def perform_create(self, serializer):
        serializer.save(user=self.request.user)



"""
Plugs Media Settings
"""

from django.conf import settings

PROJECT_SETTINGS = getattr(settings, 'PLUGS_MEDIA', {})

DEFAULTS = {
    'CONTENT_TYPES': [
        'image/png',
        'image/jpeg',
        'image/gif',
        'application/pdf'
    ],
    'MAX_FILE_SIZE': 2000000
}

for setting in DEFAULTS.keys():
    if setting not in PROJECT_SETTINGS:
        PROJECT_SETTINGS[setting] = DEFAULTS[setting]

plugs_media_settings = PROJECT_SETTINGS
